==> acceleratedrendering-1.0.5.1-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/features/entities/mixins/InventoryScreenMixin.java <==
package com.github.argon4w.acceleratedrendering.features.entities.mixins;

import com.github.argon4w.acceleratedrendering.core.CoreBuffers;
import com.github.argon4w.acceleratedrendering.core.CoreFeature;
import com.github.argon4w.acceleratedrendering.core.CoreStates;
import com.github.argon4w.acceleratedrendering.core.buffers.accelerated.layers.LayerDrawType;
import net.minecraft.class_1309;
import net.minecraft.class_332;
import net.minecraft.class_490;
import net.minecraft.class_898;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_490.class)
public class InventoryScreenMixin {

	@Inject(method = "method_29977", at = @At("HEAD"))
	private static void startRenderingGui(
			class_898	entityrenderdispatcher,
			class_1309			entity,
			class_332				guiGraphics,
			CallbackInfo			ci
	) {
		CoreFeature.setRenderingGui();
	}

	@Inject(method = "method_29977", at = @At("TAIL"))
	private static void stopRenderingGui(
			class_898	entityrenderdispatcher,
			class_1309			entity,
			class_332				guiGraphics,
			CallbackInfo			ci
	) {
		CoreFeature.resetRenderingGui();

		if (!CoreFeature.isGuiBatching()) {
			CoreStates						.record			();
			CoreBuffers.ENTITY				.prepareBuffers	();
			CoreBuffers.BLOCK				.prepareBuffers	();
			CoreBuffers.POS					.prepareBuffers	();
			CoreBuffers.POS_TEX				.prepareBuffers	();
			CoreBuffers.POS_TEX_COLOR		.prepareBuffers	();
			CoreBuffers.POS_COLOR_TEX_LIGHT	.prepareBuffers	();
			CoreStates						.restore		();

			CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS					.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.ALL);

			CoreBuffers.ENTITY				.clearBuffers	();
			CoreBuffers.BLOCK				.clearBuffers	();
			CoreBuffers.POS					.clearBuffers	();
			CoreBuffers.POS_TEX				.clearBuffers	();
			CoreBuffers.POS_TEX_COLOR		.clearBuffers	();
			CoreBuffers.POS_COLOR_TEX_LIGHT	.clearBuffers	();
		}
	}
}

==> acceleratedrendering-1.0.6-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/features/entities/mixins/InventoryScreenMixin.java <==
package com.github.argon4w.acceleratedrendering.features.entities.mixins;

import com.github.argon4w.acceleratedrendering.core.CoreBuffers;
import com.github.argon4w.acceleratedrendering.core.CoreFeature;
import com.github.argon4w.acceleratedrendering.core.CoreStates;
import com.github.argon4w.acceleratedrendering.core.buffers.accelerated.layers.LayerDrawType;
import net.minecraft.class_1309;
import net.minecraft.class_332;
import net.minecraft.class_490;
import net.minecraft.class_898;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_490.class)
public class InventoryScreenMixin {

	@Inject(method = "method_29977", at = @At("HEAD"))
	private static void startRenderingGui(
			class_898	entityrenderdispatcher,
			class_1309			entity,
			class_332				guiGraphics,
			CallbackInfo			ci
	) {
		CoreFeature.setRenderingGui();
	}

	@Inject(method = "method_29977", at = @At("TAIL"))
	private static void stopRenderingGui(
			class_898	entityrenderdispatcher,
			class_1309			entity,
			class_332				guiGraphics,
			CallbackInfo			ci
	) {
		CoreFeature.resetRenderingGui();

		if (!CoreFeature.isGuiBatching()) {
			CoreStates						.recordBuffers	();
			CoreBuffers.ENTITY				.prepareBuffers	();
			CoreBuffers.BLOCK				.prepareBuffers	();
			CoreBuffers.POS					.prepareBuffers	();
			CoreBuffers.POS_TEX				.prepareBuffers	();
			CoreBuffers.POS_TEX_COLOR		.prepareBuffers	();
			CoreBuffers.POS_COLOR_TEX_LIGHT	.prepareBuffers	();
			CoreStates						.restoreBuffers	();

			CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS					.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.ALL);
			CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.ALL);

			CoreBuffers.ENTITY				.clearBuffers	();
			CoreBuffers.BLOCK				.clearBuffers	();
			CoreBuffers.POS					.clearBuffers	();
			CoreBuffers.POS_TEX				.clearBuffers	();
			CoreBuffers.POS_TEX_COLOR		.clearBuffers	();
			CoreBuffers.POS_COLOR_TEX_LIGHT	.clearBuffers	();
		}
	}
}
